Contributions and feedback of all kind are welcome! Please see below how to
best reach us or contribute.

Submitting an issue
===================

If you have questions about the use of the package please consider contacting
us via the [mailing list][1]

If you find a bug or have concrete suggestions for improvements feel free to
open an issue on the [Github issue tracker][2].

Submitting an patch/pull request
================================

Patches and pull requests can also be submitted via Github. Please include your
name in the copyright statement at the beginning of the file.

Styleguide
----------

In order to keep the code readable we follow the [PEP8 Style Guide][3].
We use [ruff][4] to automatically format and check code style.
Consider checking your contribution by running `ruff format` and `ruff check` in the root directory of the package.

Notable exceptions are docstrings for which we follow the [numpydoc style][5].

[1]: https://sourceforge.net/p/xrayutilities/mailman/xrayutilities-users
[2]: https://github.com/dkriegner/xrayutilities/issues
[3]: https://www.python.org/dev/peps/pep-0008/
[4]: https://docs.astral.sh/ruff/
[5]: http://numpydoc.readthedocs.io
